[MOBY-guts] biomoby commit

Paul Gordon gordonp at dev.open-bio.org
Mon Mar 29 20:53:05 UTC 2010


gordonp
Mon Mar 29 16:53:04 EDT 2010
Update of /home/repository/moby/moby-live/Java/src/main/ca/ucalgary/seahawk/util
In directory dev.open-bio.org:/tmp/cvs-serv12560/src/main/ca/ucalgary/seahawk/util

Modified Files:
	DataFlowRecorder.java 
Log Message:
Fixed old DataRecorder refs in documentation
moby-live/Java/src/main/ca/ucalgary/seahawk/util DataFlowRecorder.java,1.1,1.2
===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/ca/ucalgary/seahawk/util/DataFlowRecorder.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- /home/repository/moby/moby-live/Java/src/main/ca/ucalgary/seahawk/util/DataFlowRecorder.java	2010/03/29 19:58:17	1.1
+++ /home/repository/moby/moby-live/Java/src/main/ca/ucalgary/seahawk/util/DataFlowRecorder.java	2010/03/29 20:53:04	1.2
@@ -48,7 +48,7 @@
 
     public DataFlowRecorder(Central mobyCtr) throws Exception{
 	if(mobyCtr == null){
-	    throw new IllegalArgumentException("Moby Central object passed to DataRecorder was null");
+	    throw new IllegalArgumentException("Moby Central object passed to DataFlowRecorder was null");
 	}
 	mobyCentral = mobyCtr;
 	DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
@@ -67,12 +67,12 @@
      * @param resultDocuments the output of the workflow to backtrace
      * @param outputStream where to write the output
      * @param workflowName to be used as a label in the workflow
      * @param format the format to write the workflow in (currently, only DataRecorder.T2FLOW works)
      */
     public void exportWorkflow(Map<URL,FilterSearch> resultDocuments, OutputStream outputStream, String workflowName, String workflowTitle, String workflowDescription, String workflowAuthor, int format) throws Exception{
 	if(format != TAVERNA15 && format != T2FLOW){
 	    throw new IllegalArgumentException("The export format for the workflow was " +
-					       "not DataRecorder.TAVERNA15 nor DataRecorder.T2FLOW as expected, found " + format);
+					       "not DataFlowRecorder.TAVERNA15 nor DataFlowRecorder.T2FLOW as expected, found " + format);
 	}
 	if(outputStream == null){
 	    throw new IllegalArgumentException("The output stream for workflow exporting was null, aborting export");
@@ -720,7 +720,7 @@
     }
 
     // Retrieves the port name that can be used in a datalink.  Since it is of local 
     // scope, we can just call it the same as the moby param.  DataRecorder sets up provenance 
     // URLs (during calls to saveInput) of the form URLOfMobyXML#/path/based/on/Simple[@articleName = "foo"]/datatype
     // We also pass in the processors and datalinks because we may need to add some ourselves
     // When extra processors are added to filter a collection by namespace, etc.
@@ -67,12 +67,12 @@
      * @param outputStream where to write the output
      * @param workflowName to be used as a label in the workflow
-     * @param format the format to write the workflow in (currently, only DataRecorder.T2FLOW works)
+     * @param format the format to write the workflow in (currently, only DataFlowRecorder.T2FLOW works)
      */
     public void exportWorkflow(Map<URL,FilterSearch> resultDocuments, OutputStream outputStream, String workflowName, String workflowTitle, String workflowDescription, String workflowAuthor, int format) throws Exception{
@@ -720,7 +720,7 @@
 
     // Retrieves the port name that can be used in a datalink.  Since it is of local 
-    // scope, we can just call it the same as the moby param.  DataRecorder sets up provenance 
+    // scope, we can just call it the same as the moby param.  DataFlowRecorder sets up provenance 
     // URLs (during calls to saveInput) of the form URLOfMobyXML#/path/based/on/Simple[@articleName = "foo"]/datatype
     // We also pass in the processors and datalinks because we may need to add some ourselves




More information about the MOBY-guts mailing list